@@ -29,7 +29,7 @@ Class handling language-specific displaying of names.
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from TransUtils import sgettext as _
 import re
 
 #-------------------------------------------------------------------------
@@ -86,7 +86,7 @@ def _make_cmp(a,b): return -cmp(a[1], b[1])
 # NameDisplay class
 #
 #-------------------------------------------------------------------------
-class NameDisplay:
+class NameDisplay(object):
     """
     Base class for displaying of Name instances.
     """
@@ -166,7 +166,7 @@ class NameDisplay:
         for (num, name,fmt_str,act) in formats:
             func = self._format_fn(fmt_str)
             func_raw = raw_func_dict.get(num)
-            if func_raw == None:
+            if func_raw is None:
                 func_raw = self._format_raw_fn(fmt_str)
             self.name_formats[num] = (name,fmt_str,act,func,func_raw)
 
@@ -276,7 +276,7 @@ class NameDisplay:
         # we need the names of each of the variables or methods that are
         # called to fill in each format flag.
         # Dictionary is "code": ("expression", "keyword", "i18n-keyword")
-        d = {"t": ("raw_data[_TITLE]",     "title",      _("title")),
+        d = {"t": ("raw_data[_TITLE]",     "title",      _("Person|title")),
              "f": ("raw_data[_FIRSTNAME]", "given",      _("given")),
              "p": ("raw_data[_PREFIX]",    "prefix",     _("prefix")),
              "l": ("raw_data[_SURNAME]",   "surname",    _("surname")),
@@ -315,7 +315,7 @@ class NameDisplay:
         # we need the names of each of the variables or methods that are
         # called to fill in each format flag.
         # Dictionary is "code": ("expression", "keyword", "i18n-keyword")
-        d = {"t": ("title",      "title",      _("title")),
+        d = {"t": ("title",      "title",      _("Person|title")),
              "f": ("first",      "given",      _("given")),
              "p": ("prefix",     "prefix",     _("prefix")),
              "l": ("surname",    "surname",    _("surname")),
@@ -334,43 +334,57 @@ class NameDisplay:
         Create the name display function and handles dependent
         punctuation.
         """
+        # d is a dict: dict[code] = (expr, word, translated word)
+
         # First, go through and do internationalization-based
         # key-word replacement. Just replace ikeywords with
         # %codes (ie, replace "irstnamefay" with "%f", and
         # "IRSTNAMEFAY" for %F)
-        d_keys = [(code, d[code][2]) for code in d.keys()]
-        d_keys.sort(_make_cmp) # reverse sort by ikeyword
-        for (code, ikeyword) in d_keys:
-            exp, keyword, ikeyword = d[code]
-            format_str = format_str.replace(ikeyword,"%"+ code)
-            format_str = format_str.replace(ikeyword.title(),"%"+ code)
-            format_str = format_str.replace(ikeyword.upper(),"%"+ code.upper())
+        if (len(format_str) > 2 and 
+            format_str[0] == '"' and 
+            format_str[-1] == '"'):
+            pass
+        else:
+            d_keys = [(code, d[code][2]) for code in d.keys()]
+            d_keys.sort(_make_cmp) # reverse sort by ikeyword
+            for (code, ikeyword) in d_keys:
+                exp, keyword, ikeyword = d[code]
+                ikeyword = unicode(ikeyword, "utf8")
+                format_str = format_str.replace(ikeyword,"%"+ code)
+                format_str = format_str.replace(ikeyword.title(),"%"+ code)
+                format_str = format_str.replace(ikeyword.upper(),"%"+ code.upper())
         # Next, go through and do key-word replacement.
         # Just replace keywords with
         # %codes (ie, replace "firstname" with "%f", and
         # "FIRSTNAME" for %F)
-        d_keys = [(code, d[code][1]) for code in d.keys()]
-        d_keys.sort(_make_cmp) # reverse sort by keyword
-        for (code, keyword) in d_keys:
-            exp, keyword, ikeyword = d[code]
-            format_str = format_str.replace(keyword,"%"+ code)
-            format_str = format_str.replace(keyword.title(),"%"+ code)
-            format_str = format_str.replace(keyword.upper(),"%"+ code.upper())
+        if (len(format_str) > 2 and 
+            format_str[0] == '"' and 
+            format_str[-1] == '"'):
+            format_str = format_str[1:-1]
+        else:
+            d_keys = [(code, d[code][1]) for code in d.keys()]
+            d_keys.sort(_make_cmp) # reverse sort by keyword
+            # if in double quotes, just use % codes
+            for (code, keyword) in d_keys:
+                exp, keyword, ikeyword = d[code]
+                keyword = unicode(keyword, "utf8")
+                format_str = format_str.replace(keyword,"%"+ code)
+                format_str = format_str.replace(keyword.title(),"%"+ code)
+                format_str = format_str.replace(keyword.upper(),"%"+ code.upper())
         # Get lower and upper versions of codes:
         codes = d.keys() + [c.upper() for c in d.keys()]
         # Next, list out the matching patterns:
         # If it starts with "!" however, treat the punctuation verbatim:
         if len(format_str) > 0 and format_str[0] == "!":
-            format_str = format_str[1:]
             patterns = ["%(" + ("|".join(codes)) + ")",          # %s
                         ]
+            format_str = format_str[1:]
         else:
             patterns = [",\W*\(%(" + ("|".join(codes)) + ")\)",  # ,\W*(%s)
                         ",\W*%(" + ("|".join(codes)) + ")",      # ,\W*%s
                         "\(%(" + ("|".join(codes)) + ")\)",      # (%s)
                         "%(" + ("|".join(codes)) + ")",          # %s
                         ]
-
         new_fmt = format_str
 
         # replace the specific format string flags with a 
@@ -406,7 +420,6 @@ def fn(%s):
         else:
             return p + str + s
     return "%s" %% (%s)""" % (args, new_fmt, ",".join(param))
-
         exec(s)
 
         return fn
@@ -425,7 +438,7 @@ def fn(%s):
         method call and we need all the speed we can squeeze out of this.
         """
         func = self.__class__.raw_format_funcs.get(format_str)
-        if func == None:
+        if func is None:
             func = self._gen_raw_func(format_str)
             self.__class__.raw_format_funcs[format_str] = func
 
@@ -453,7 +466,7 @@ def fn(%s):
         All the other characters in the fmt_str are unaffected.
         """
         func = self.__class__.format_funcs.get(format_str)
-        if func == None:
+        if func is None:
             func = self._gen_cooked_func(format_str)
             self.__class__.format_funcs[format_str] = func
         try:
@@ -553,7 +566,7 @@ def fn(%s):
         @returns: Returns the L{Name} string representation
         @rtype: str
         """
-        if name == None:
+        if name is None:
             return ""
 
         num = self._is_format_valid(name.display_as)
