@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Bookmarks.py 10367 2008-03-21 22:39:34Z bmcage $
+# $Id: Bookmarks.py 13171 2009-09-08 08:28:29Z ldnp $
 
 "Handle bookmarks for the gramps interface."
 
@@ -54,6 +54,7 @@ import GrampsDisplay
 from BasicUtils import name_displayer
 import ListModel
 import Utils
+import const
 from TransUtils import sgettext as _
 
 #-------------------------------------------------------------------------
@@ -61,7 +62,7 @@ from TransUtils import sgettext as _
 # Constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Navigation'
+WIKI_HELP_PAGE = '%s_-_Navigation' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Bookmarks')
 
 #-------------------------------------------------------------------------
@@ -231,12 +232,17 @@ class Bookmarks :
         delete.connect('clicked', self.delete_clicked)
         self.top.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
         self.top.add_button(gtk.STOCK_HELP, gtk.RESPONSE_HELP)
+        self.top.connect('delete-event', self.close)
         bbox.add(up)
         bbox.add(down)
         bbox.add(delete)
         box.pack_start(bbox, 0, 0, 5)
         self.top.show_all()
-        
+    
+    def close(self, widget, event):
+        """Stop the bookmark organizer"""
+        self.top.response(gtk.RESPONSE_CLOSE)
+
     def edit(self):
         """
         Display the bookmark editor.
@@ -306,8 +312,7 @@ class Bookmarks :
 
     def help_clicked(self):
         """Display the relevant portion of GRAMPS manual."""
-        GrampsDisplay.help('gramps-nav', webpage=WIKI_HELP_PAGE, 
-                                   section=WIKI_HELP_SEC)
+        GrampsDisplay.help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
 class ListBookmarks(Bookmarks):
 
@@ -423,6 +428,8 @@ class NoteBookmarks(ListBookmarks) :
     def make_label(self, handle):
         obj = self.dbstate.db.get_note_from_handle(handle)
         name = obj.get().replace('\n', ' ')
+        #String must be unicode for truncation to work for non ascii characters
+        name = unicode(name)
         if len(name) > 40:
             name = name[:40]+"..."
         return ("%s [%s]" % (name, obj.gramps_id), obj)
