@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _DateDisplay.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _DateDisplay.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 U.S English date display class. Should serve as the base class for all
@@ -46,7 +46,7 @@ import GrampsLocale
 # DateDisplay
 #
 #-------------------------------------------------------------------------
-class DateDisplay:
+class DateDisplay(object):
 
     _months = GrampsLocale.long_months
     MONS   = GrampsLocale.short_months
@@ -88,12 +88,21 @@ class DateDisplay:
         "Ramadan", "Shawwal", "Dhu l-Qa`da", "Dhu l-Hijja"
         )
 
+    swedish = (
+        "", "Januari", "Februari", "Mars",
+        "April", "Maj", "Juni",
+        "Juli", "Augusti", "September",
+        "Oktober", "November", "December"
+        )
+
     formats = ("YYYY-MM-DD (ISO)", )
 
     calendar = (
-        "", " (Julian)", " (Hebrew)", " (French Republican)", 
-        " (Persian)", " (Islamic)"
+        "", "Julian", "Hebrew", "French Republican", 
+        "Persian", "Islamic", "Swedish" 
         )
+
+    newyear = ("", "Mar1", "Mar25", "Sep1")
     
     _mod_str = ("", "before ", "after ", "about ", "", "", "")
 
@@ -109,10 +118,10 @@ class DateDisplay:
             self._display_french, 
             self._display_persian, 
             self._display_islamic, 
-            ]
+            self._display_swedish]
 
         self.verify_format(format)
-        if format == None:
+        if format is None:
             self.format = 0
         else:
             self.format = format
@@ -133,6 +142,22 @@ class DateDisplay:
         else:
             return self.display(date)
 
+    def format_extras(self, cal, newyear):
+        """
+        Formats the extra items (calendar, newyear) for a date.
+        """
+        scal = self.calendar[cal]
+        snewyear = self.newyear[newyear]
+        retval = ""
+        for item in [scal, snewyear]:
+            if item:
+                if retval:
+                    retval += ","
+                retval += item
+        if retval:
+            return " (%s)" % retval
+        return ""
+
     def display(self, date):
         """
         Return a text string representing the date.
@@ -141,6 +166,7 @@ class DateDisplay:
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -151,23 +177,24 @@ class DateDisplay:
         elif mod == Date.MOD_SPAN or mod == Date.MOD_RANGE:
             d1 = self.display_iso(start)
             d2 = self.display_iso(date.get_stop_date())
-            return "%s %s - %s%s" % (qual_str, d1, d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s %s - %s%s" % (qual_str, d1, d2, scal)
         else:
             text = self.display_iso(start)
-            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, 
-                                 self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, scal)
 
     def _slash_year(self, val, slash):
         if val < 0:
             val = - val
             
         if slash:
-            if val % 100 == 99:
-                year = "%d/%d" % (val, (val%1000)+1)
-            elif val % 10 == 9:
-                year = "%d/%d" % (val, (val%100)+1)
+            if (val-1) % 100 == 99:
+                year = "%d/%d" % (val - 1, (val%1000))
+            elif (val-1) % 10 == 9:
+                year = "%d/%d" % (val - 1, (val%100))
             else:
-                year = "%d/%d" % (val, (val%10)+1)
+                year = "%d/%d" % (val - 1, (val%10))
         else:
             year = "%d" % (val)
         
@@ -177,7 +204,7 @@ class DateDisplay:
         # YYYY-MM-DD (ISO)
         year = self._slash_year(date_val[2], date_val[3])
         # This produces 1789, 1789-00-11 and 1789-11-00 for incomplete dates.
-        if date_val[0] == 0 and date_val[1] == 0:
+        if date_val[0] == date_val[1] == 0:
             # No month and no day -> year
             value = year
         else:
@@ -203,7 +230,7 @@ class DateDisplay:
             if date_val[3]:
                 return self.display_iso(date_val)
             else:
-                if date_val[0] == 0 and date_val[1] == 0:
+                if date_val[0] == date_val[1] == 0:
                     value = str(date_val[2])
                 else:
                     value = self._tformat.replace('%m', str(date_val[1]))
@@ -301,6 +328,9 @@ class DateDisplay:
     def _display_islamic(self, date_val):
         return self._display_calendar(date_val, self.islamic)
 
+    def _display_swedish(self, date_val):
+        return self._display_calendar(date_val, self.swedish)
+
 class DateDisplayEn(DateDisplay):
     """
     English language date display class. 
@@ -328,6 +358,7 @@ class DateDisplayEn(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -338,13 +369,14 @@ class DateDisplayEn(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%sfrom %s to %s%s" % (qual_str, d1, d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%sfrom %s to %s%s" % (qual_str, d1, d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%sbetween %s and %s%s" % (qual_str, d1, d2, 
-                                              self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%sbetween %s and %s%s" % (qual_str, d1, d2, scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
-            return "%s%s%s%s" % (qual_str, self._mod_str[mod], 
-                                 text, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, scal)
