@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _DateParser.py 10855 2008-07-14 12:17:40Z bmcage $
+# $Id: _DateParser.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Date parsing class. Serves as the base class for any localized
@@ -60,6 +60,7 @@ _max_days  = [ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ]
 _leap_days = [ 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 ]
 
 def gregorian_valid(date_tuple):
+    """ Checks if date_tuple is a valid date in Gregorian Calendar  """
     day = date_tuple[0]
     month = date_tuple[1]
     valid = True
@@ -75,12 +76,53 @@ def gregorian_valid(date_tuple):
         valid = False
     return valid
 
+def julian_valid(date_tuple):
+    """ Checks if date_tuple is a valid date in Julian Calendar """
+    day = date_tuple[0]
+    month = date_tuple[1]
+    valid = True
+    try:
+        if month > 12:
+            valid = False
+        elif (date_tuple[2]) % 4 == 0:
+            # julian always have leapyear every 4 year
+            if day > _leap_days[month-1]:
+                valid = False
+        elif day > _max_days[month-1]:
+            valid = False
+    except:
+        valid = False
+    return valid
+
+def swedish_valid(date_tuple):
+    """ Checks if date_tuple is a valid date in Swedish Calendar """
+    valid = gregorian_valid(date_tuple)
+    # not sure how <= and >= works with tuples???
+    date_tuple = (date_tuple[2], date_tuple[1], date_tuple[0])
+    if date_tuple <= (1700, 2, 28):
+        valid = False 
+    if date_tuple == (1700, 2, 29):  # leapday 1700 was skipped
+        valid = False 
+    if date_tuple == (1712, 2, 30):  # extra day was inserted 1712
+        valid = True 
+    if date_tuple >= (1712, 3, 1):   # back to julian
+        valid = False
+    return valid
+
+def french_valid(date_tuple):
+    """ Checks if date_tuple is a valid date in French Calendar """
+    valid = True
+    # year 1 starts on 22.9.1792
+    if date_tuple[2] < 1:
+        valid = False       
+    return valid
+
 #-------------------------------------------------------------------------
 #
 # Parser class
 #
 #-------------------------------------------------------------------------
-class DateParser:
+class DateParser(object):
     """
     Convert a text string into a Date object. If the date cannot be
     converted, the text string is assigned.
@@ -156,6 +198,16 @@ class DateParser:
         "bahman"      : 11, "esfand"      : 12,
         }
 
+    swedish_to_int = {
+        "januari"    :  1, "februari"   :  2,
+        "mars"       :  3, "april"      :  4,
+        "maj"        :  5, "juni"       :  6,
+        "juli"       :  7, "augisti"    :  8,
+        "september"  :  9, "oktober"    : 10,
+        "november"   : 11, "december"   : 12,
+        }
+        
+
     bce = ["B.C.E.", "B.C.E", "BCE", "B.C.", "B.C", "BC" ]
 
     calendar_to_int = {
@@ -171,7 +223,16 @@ class DateParser:
         'french republican': Date.CAL_FRENCH,
         'f'                : Date.CAL_FRENCH,
         'persian'          : Date.CAL_PERSIAN,
-        'p'                : Date.CAL_PERSIAN,
+        'p'                : Date.CAL_PERSIAN, 
+        'swedish'          : Date.CAL_SWEDISH,
+        's'                : Date.CAL_SWEDISH,
+        }
+
+    newyear_to_int = {
+        "jan1":  Date.NEWYEAR_JAN1,
+        "mar1":  Date.NEWYEAR_MAR1,
+        "mar25": Date.NEWYEAR_MAR25, 
+        "sep1" : Date.NEWYEAR_SEP1,
         }
     
     quality_to_int = {
@@ -186,12 +247,13 @@ class DateParser:
     def __init__(self):
         self.init_strings()
         self.parser = {
-            Date.CAL_GREGORIAN : self._parse_greg_julian,
-            Date.CAL_JULIAN    : self._parse_greg_julian,
+            Date.CAL_GREGORIAN : self._parse_gregorian,
+            Date.CAL_JULIAN    : self._parse_julian,
             Date.CAL_FRENCH    : self._parse_french,
             Date.CAL_PERSIAN   : self._parse_persian,
             Date.CAL_HEBREW    : self._parse_hebrew,
             Date.CAL_ISLAMIC   : self._parse_islamic,
+            Date.CAL_SWEDISH   : self._parse_swedish,
             }
 
         fmt = GrampsLocale.tformat
@@ -239,7 +301,9 @@ class DateParser:
         self._fmon_str = self.re_longest_first(self.french_to_int.keys())
         self._pmon_str = self.re_longest_first(self.persian_to_int.keys())
         self._imon_str = self.re_longest_first(self.islamic_to_int.keys())
+        self._smon_str = self.re_longest_first(self.swedish_to_int.keys())
         self._cal_str  = self.re_longest_first(self.calendar_to_int.keys())
+        self._ny_str = self.re_longest_first(self.newyear_to_int.keys())
 
         # bce, calendar type and quality may be either at the end or at
         # the beginning of the given date string, therefore they will
@@ -248,6 +312,11 @@ class DateParser:
 
         self._cal      = re.compile("(.*)\s+\(%s\)( ?.*)" % self._cal_str,
                                     re.IGNORECASE)
+        self._calny    = re.compile("(.*)\s+\(%s,%s\)( ?.*)" % (self._cal_str,
+                                                                self._ny_str),
+                                   re.IGNORECASE)
+        self._ny    = re.compile("(.*)\s+\(%s\)( ?.*)" % self._ny_str,
+                                 re.IGNORECASE)
         self._qual     = re.compile("(.* ?)%s\s+(.+)" % self._qual_str,
                                     re.IGNORECASE)
         
@@ -280,6 +349,10 @@ class DateParser:
                                     re.IGNORECASE)
         self._itext2   = re.compile('(\d+)?\s+?%s\s*((\d+)(/\d+)?)?\s*$' % self._imon_str,
                                     re.IGNORECASE)
+        self._stext     = re.compile('%s\.?\s+(\d+)?\s*,?\s*((\d+)(/\d+)?)?\s*$' % self._smon_str,
+                                    re.IGNORECASE)
+        self._stext2    = re.compile('(\d+)?\s+?%s\.?\s*((\d+)(/\d+)?)?\s*$' % self._smon_str,
+                                    re.IGNORECASE)
         self._numeric  = re.compile("((\d+)[/\.]\s*)?((\d+)[/\.]\s*)?(\d+)\s*$")
         self._iso      = re.compile("(\d+)(/(\d+))?-(\d+)-(\d+)\s*$")
         self._rfc      = re.compile("(%s,)?\s+(\d|\d\d)\s+%s\s+(\d+)\s+\d\d:\d\d(:\d\d)?\s+(\+|-)\d\d\d\d" 
@@ -290,7 +363,7 @@ class DateParser:
         Convert the string to an integer if the value is not None. If the
         value is None, a zero is returned
         """
-        if val == None:
+        if val is None:
             return 0
         else:
             return int(val)
@@ -309,29 +382,42 @@ class DateParser:
 
     def _parse_french(self, text):
         return self._parse_calendar(text, self._ftext, self._ftext2,
-                                    self.french_to_int)
+                                    self.french_to_int, french_valid)
 
-    def _parse_greg_julian(self, text):
+    def _parse_gregorian(self, text):
         return self._parse_calendar(text, self._text, self._text2,
                                     self.month_to_int, gregorian_valid)
+
+    def _parse_julian(self, text):
+        return self._parse_calendar(text, self._text, self._text2,
+                                    self.month_to_int, julian_valid)
+
+    def _parse_swedish(self, text):
+        return self._parse_calendar(text, self._stext, self._stext2,
+                                    self.swedish_to_int,swedish_valid)
+
                              
     def _parse_calendar(self, text, regex1, regex2, mmap, check=None):
         match = regex1.match(text.lower())
         if match:
             groups = match.groups()
-            if groups[0] == None:
+            if groups[0] is None:
                 m = 0
             else:
                 m = mmap[groups[0].lower()]
 
-            if groups[2] == None:
+            if groups[2] is None:
                 y = self._get_int(groups[1])
                 d = 0
                 s = False
             else:
                 d = self._get_int(groups[1])
-                y = int(groups[3])
-                s = groups[4] != None
+                if groups[4] is not None: # slash year "/80"
+                    y = int(groups[3]) + 1 # fullyear + 1
+                    s = True
+                else: # regular, non-slash date
+                    y = int(groups[3])
+                    s = False
             value = (d, m, y, s)
             if check and not check((d, m, y)):
                 value = Date.EMPTY
@@ -340,19 +426,23 @@ class DateParser:
         match = regex2.match(text.lower())
         if match:
             groups = match.groups()
-            if groups[1] == None:
+            if groups[1] is None:
                 m = 0
             else:
                 m = mmap[groups[1].lower()]
 
             d = self._get_int(groups[0])
 
-            if groups[2] == None:
+            if groups[2] is None:
                 y = None
                 s = False
             else:
-                y = int(groups[3])
-                s = groups[4] != None
+                if groups[4] is not None: # slash year digit
+                    y = int(groups[3]) + 1 # fullyear + 1
+                    s = True
+                else:
+                    y = int(groups[3])
+                    s = False
             value = (d, m, y, s)
             if check and not check((d, m, y)):
                 value = Date.EMPTY
@@ -364,18 +454,26 @@ class DateParser:
         """
         Convert only the date portion of a date.
         """
-        if subparser == None:
-            subparser = self._parse_greg_julian
+        if subparser is None:
+            subparser = self._parse_gregorian
 
-        if subparser == self._parse_greg_julian:
+        if subparser == self._parse_gregorian:
             check = gregorian_valid
+
+        elif subparser == self._parse_julian:
+            check = julian_valid
+
+        elif subparser == self._parse_swedish:
+            check = swedish_valid
+
+        elif subparser == self._parse_french:
+            check = french_valid
         else:
             check = None
-            
+
         value = subparser(text)
         if value != Date.EMPTY:
             return value
-        
         match = self._iso.match(text)
         if match:
             groups = match.groups()
@@ -384,8 +482,8 @@ class DateParser:
             d = self._get_int(groups[4])
             if check and not check((d, m, y)):
                 return Date.EMPTY
-            if groups[2]:
-                return (d, m, y, True)
+            if groups[2]: # slash year digit
+                return (d, m, y + 1, True)
             else:
                 return (d, m, y, False)
 
@@ -405,7 +503,7 @@ class DateParser:
             groups = match.groups()
             if self.ymd:
                 # '1789' and ymd: incomplete date
-                if groups[1] == None:
+                if groups[1] is None:
                     y = self._get_int(groups[4])
                     m = 0
                     d = 0
@@ -440,6 +538,31 @@ class DateParser:
             text = match.group(1) + match.group(3)
         return (text, cal)
 
+    def match_calendar_newyear(self, text, cal, newyear):
+        """
+        Try parsing calendar and newyear code.
+        
+        Return newyear index and the text with calendar removed.
+        """
+        match = self._calny.match(text)
+        if match:
+            cal = self.calendar_to_int[match.group(2).lower()]
+            newyear = self.newyear_to_int[match.group(3).lower()]
+            text = match.group(1) + match.group(4)
+        return (text, cal, newyear)
+
+    def match_newyear(self, text, newyear):
+        """
+        Try parsing calendar and newyear code.
+        
+        Return newyear index and the text with calendar removed.
+        """
+        match = self._ny.match(text)
+        if match:
+            newyear = self.newyear_to_int[match.group(2).lower()]
+            text = match.group(1) + match.group(3)
+        return (text, newyear)
+
     def match_quality(self, text, qual):
         """
         Try matching quality.
@@ -452,7 +575,7 @@ class DateParser:
             text = match.group(1) + match.group(3)
         return (text, qual)
 
-    def match_span(self, text, cal, qual, date):
+    def match_span(self, text, cal, ny, qual, date):
         """
         Try matching span date.
         
@@ -471,11 +594,11 @@ class DateParser:
             if bc2:
                 stop = self.invert_year(stop)
 
-            date.set(qual, Date.MOD_SPAN, cal, start + stop)
+            date.set(qual, Date.MOD_SPAN, cal, start + stop, newyear=ny)
             return 1
         return 0
 
-    def match_range(self, text, cal, qual, date):
+    def match_range(self, text, cal, ny, qual, date):
         """
         Try matching range date.
         
@@ -494,7 +617,7 @@ class DateParser:
             if bc2:
                 stop = self.invert_year(stop)
             
-            date.set(qual, Date.MOD_RANGE, cal, start + stop)
+            date.set(qual, Date.MOD_RANGE, cal, start + stop, newyear=ny)
             return 1
         return 0
 
@@ -511,11 +634,11 @@ class DateParser:
             try:
                 text = match.group(1) + match.group(3)
             except:
-                print "MATCH:", match.groups()
+                print "ERROR MATCH:", match.groups()
             bc = True
         return (text, bc)
 
-    def match_modifier(self, text, cal, qual, bc, date):
+    def match_modifier(self, text, cal, ny, qual, bc, date):
         """
         Try matching date with modifier.
         
@@ -531,9 +654,9 @@ class DateParser:
                 date.set_modifier(Date.MOD_TEXTONLY)
                 date.set_text_value(text)
             elif bc:
-                date.set(qual, mod, cal, self.invert_year(start))
+                date.set(qual, mod, cal, self.invert_year(start), newyear=ny)
             else:
-                date.set(qual, mod, cal, start)
+                date.set(qual, mod, cal, start, newyear=ny)
             return True
         # modifiers after the date
         if self.modifier_after_to_int:
@@ -544,9 +667,9 @@ class DateParser:
                 mod = self.modifier_after_to_int.get(grps[1].lower(),
                                                      Date.MOD_NONE)
                 if bc:
-                    date.set(qual, mod, cal, self.invert_year(start))
+                    date.set(qual, mod, cal, self.invert_year(start), newyear=ny)
                 else:
-                    date.set(qual, mod, cal, start)
+                    date.set(qual, mod, cal, start, newyear=ny)
                 return True
         match = self._abt2.match(text)
         if match:
@@ -554,9 +677,9 @@ class DateParser:
             start = self._parse_subdate(grps[0])
             mod = Date.MOD_ABOUT
             if bc:
-                date.set(qual, mod, cal, self.invert_year(start))
+                date.set(qual, mod, cal, self.invert_year(start), newyear=ny)
             else:
-                date.set(qual, mod, cal, start)
+                date.set(qual, mod, cal, start, newyear=ny)
             return True
         return False
 
@@ -564,21 +687,24 @@ class DateParser:
         """
         Parses the text and sets the date according to the parsing.
         """
-
+        text = text.strip() # otherwise spaces can make it a bad date
         date.set_text_value(text)
         qual = Date.QUAL_NONE
         cal  = Date.CAL_GREGORIAN
+        newyear = Date.NEWYEAR_JAN1
         
+        (text, cal, newyear) = self.match_calendar_newyear(text, cal, newyear)
+        (text, newyear) = self.match_newyear(text, newyear)
         (text, cal) = self.match_calendar(text, cal)
         (text, qual) = self.match_quality(text, qual)
 
-        if self.match_span(text, cal, qual, date):
+        if self.match_span(text, cal, newyear, qual, date):
             return
-        if self.match_range(text, cal, qual, date):
+        if self.match_range(text, cal, newyear, qual, date):
             return
 
         (text, bc) = self.match_bce(text)
-        if self.match_modifier(text, cal, qual, bc, date):
+        if self.match_modifier(text, cal, newyear, qual, bc, date):
             return
 
         try:
@@ -591,13 +717,9 @@ class DateParser:
             return
 
         if bc:
-            date.set(qual, Date.MOD_NONE, cal, self.invert_year(subdate))
+            date.set(qual, Date.MOD_NONE, cal, self.invert_year(subdate), newyear=newyear)
         else:
-            date.set(qual, Date.MOD_NONE, cal, subdate)
-
-        if date.get_slash():
-            date.set_calendar(Date.CAL_JULIAN)
-            date.set_year(date.get_year() + 1) # year++ and forces recalc
+            date.set(qual, Date.MOD_NONE, cal, subdate, newyear=newyear)
 
     def invert_year(self, subdate):
         return (subdate[0], subdate[1], -subdate[2], subdate[3])
