@@ -69,6 +69,8 @@ class DateParserCZ(DateParser):
         u'r'             : Date.CAL_FRENCH, 
         u'perský'       : Date.CAL_PERSIAN, 
         u'p'             : Date.CAL_PERSIAN, 
+        u'švédský'       : Date.CAL_SWEDISH, 
+        u's'             : Date.CAL_SWEDISH, 
         }
 
     quality_to_int = {
@@ -100,7 +102,8 @@ class DateDisplayCZ(DateDisplay):
 
     calendar = (
         "", u" (juliánský)", u" (hebrejský)", 
-        u" (republikánský)", u" (perský)", u" (islámský)"
+        u" (republikánský)", u" (perský)", u" (islámský)", 
+        u" (švédský)" 
         )
 
     _mod_str = ("", u"před ", u"po ", u"kolem ", "", "", "")
@@ -135,7 +138,7 @@ class DateDisplayCZ(DateDisplay):
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'medzi', 
+            return "%s%s %s %s %s%s" % (qual_str, u'mezi', 
                                         d1, u'a', d2, self.calendar[cal])
         else:
             text = self.display_cal[date.get_calendar()](start)
@@ -147,4 +150,4 @@ class DateDisplayCZ(DateDisplay):
 # Register classes
 #
 #-------------------------------------------------------------------------
-register_datehandler(('cs_CZ', 'cs', 'CZ', 'Czech', 'czech'), DateParserCZ, DateDisplayCZ)
+register_datehandler(('cs_CZ', 'cs', 'CZ', 'Czech'), DateParserCZ, DateDisplayCZ)
