@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,15 +18,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _PeopleModel.py 8013 2007-01-30 04:35:13Z dallingham $
+# $Id: _PeopleModel.py 13517 2009-11-07 13:24:50Z bmcage $
 
 """
 TreeModel for the GRAMPS Person tree.
 """
 
-__author__ = "Donald N. Allingham"
-__revision__ = "$Revision: 8013 $"
-
 #-------------------------------------------------------------------------
 #
 # Standard python modules
@@ -35,7 +32,6 @@ __revision__ = "$Revision: 8013 $"
 from gettext import gettext as _
 import time
 import cgi
-import sys
 import locale
 
 #-------------------------------------------------------------------------
@@ -44,7 +40,7 @@ import locale
 #
 #-------------------------------------------------------------------------
 import logging
-log = logging.getLogger(".")
+_LOG = logging.getLogger(".gui.peoplemodel")
 
 #-------------------------------------------------------------------------
 #
@@ -59,26 +55,20 @@ import gtk
 #
 #-------------------------------------------------------------------------
 import const
-from RelLib import *
-import NameDisplay
+from gen.lib import Name, EventRef, EventType, EventRoleType, MarkerType
+from BasicUtils import name_displayer
 import DateHandler
 import ToolTips
 import GrampsLocale
 import Config
+from gen.utils.longop import LongOpStatus
 from Filters import SearchFilter, ExactSearchFilter
 from Lru import LRU
 
 _CACHE_SIZE = 250
+invalid_date_format = Config.get(Config.INVALID_DATE_FORMAT)
 
-def locale_sort(mylist):
-    """
-    Normal sort routine
-    """
-    l = [ (locale.strxfrm(x),x) for x in mylist ]
-    l.sort()
-    return [ x[1] for x in l ]
-
-class NodeTreeMap:
+class NodeTreeMap(object):
 
     def __init__(self):
 
@@ -102,7 +92,9 @@ class NodeTreeMap:
         self.temp_sname_sub = {}
 
     def build_toplevel(self):
-        self.temp_top_path2iter = locale_sort(self.temp_sname_sub.keys())
+        mylist = self.temp_sname_sub.keys()
+        mylist.sort(locale.strcoll)
+        self.temp_top_path2iter = mylist
         for name in self.temp_top_path2iter:
             self.build_sub_entry(name)
 
@@ -135,7 +127,7 @@ class NodeTreeMap:
             return (self.top_iter2path[surname], index)
 
     def has_entry(self, handle):
-        return self.iter2path.has_key(handle)
+        return handle in self.iter2path
 
     def get_iter(self, path):
         try:
@@ -148,7 +140,7 @@ class NodeTreeMap:
             return None
         
     def has_top_node(self, node):
-        return self.sname_sub.has_key(node)
+        return node in self.sname_sub
 
     def find_next_node(self, node):
         try:
@@ -161,20 +153,20 @@ class NodeTreeMap:
             return self.path2iter.get((surname, val+1))
 
     def first_child(self, node):
-        if node == None:
+        if node is None:
             return self.top_path2iter[0]
         else:
             return self.path2iter.get((node, 0))
 
     def has_child(self, node):
-        if node == None:
+        if node is None:
             return len(self.sname_sub)
-        if self.sname_sub.has_key(node) and len(self.sname_sub[node]) > 0:
+        if node in self.sname_sub and len(self.sname_sub[node]) > 0:
             return True
         return False
 
     def number_of_children(self, node):
-        if node == None:
+        if node is None:
             return len(self.sname_sub)
         try:
             return len(self.sname_sub[node])
@@ -183,7 +175,7 @@ class NodeTreeMap:
 
     def get_nth_child(self, node, n):
         try:
-            if node == None:
+            if node is None:
                 return self.top_path2iter[n]
             try:
                 return self.path2iter[(node, n)]
@@ -199,9 +191,9 @@ class NodeTreeMap:
         return None
 
     def build_sub_entry(self, name):
-        slist = [ (locale.strxfrm(self.sortnames[x]), x) \
+        slist = [ (self.sortnames[x], x) \
                   for x in self.temp_sname_sub[name] ]
-        slist.sort()
+        slist.sort(lambda x, y: locale.strcoll(x[0], y[0]))
 
         val = 0
         for (junk, person_handle) in slist:
@@ -251,10 +243,11 @@ class PeopleModel(gtk.GenericTreeModel):
         """
         Initialize the model building the initial data
         """
+        cput = time.clock()
         gtk.GenericTreeModel.__init__(self)
 
         self.db = db
-	self.in_build = False
+        self.in_build = False
 
         Config.client.notify_add("/apps/gramps/preferences/todo-color",
                                  self.update_todo)
@@ -272,6 +265,9 @@ class PeopleModel(gtk.GenericTreeModel):
 
         self.mapper = NodeTreeMap()
 
+        self.total = 0
+        self.displayed = 0
+
         if filter_info and filter_info != (1, (0, u'', False)):
             if filter_info[0] == PeopleModel.GENERIC:
                 data_filter = filter_info[1]
@@ -296,6 +292,8 @@ class PeopleModel(gtk.GenericTreeModel):
             data_filter = None
         self.current_filter = data_filter
         self.rebuild_data(data_filter, skip)
+        _LOG.debug(self.__class__.__name__ + ' __init__ ' +
+                    str(time.clock() - cput) + ' sec')
 
     def update_todo(self,client,cnxn_id,entry,data):
         self.todo_color = Config.get(Config.TODO_COLOR)
@@ -310,47 +308,66 @@ class PeopleModel(gtk.GenericTreeModel):
         """
         Convience function that calculates the new data and assigns it.
         """
+        cput = time.clock()
         self.calculate_data(data_filter, skip)
         self.assign_data()
         self.current_filter = data_filter
+        _LOG.debug(self.__class__.__name__ + ' rebuild_data ' +
+                    str(time.clock() - cput) + ' sec')
         
     def _build_search_sub(self,dfilter, skip):
 
-        ngn = NameDisplay.displayer.name_grouping_data
-        nsn = NameDisplay.displayer.raw_sorted_name
+        ngn = name_displayer.name_grouping_data
+        nsn = name_displayer.raw_sorted_name
 
         self.mapper.clear_sort_names()
 
         cursor = self.db.get_person_cursor()
         node = cursor.first()
 
+        self.total = 0
+        self.displayed = 0
+
         while node:
+            self.total += 1
             handle, d = node
-            if not (handle in skip or (dfilter and not dfilter.match(handle))):
+            if not (handle in skip or (dfilter and not dfilter.match(handle,self.db))):
                 name_data = d[PeopleModel._NAME_COL]
 
                 group_name = ngn(self.db, name_data)
                 sorted_name = nsn(name_data)
-
+                self.displayed += 1
                 self.mapper.assign_sort_name(handle, sorted_name, group_name)
             node = cursor.next()
         cursor.close()
 
     def _build_filter_sub(self,dfilter, skip):
 
-        ngn = NameDisplay.displayer.name_grouping_data
-        nsn = NameDisplay.displayer.raw_sorted_name
+        ngn = name_displayer.name_grouping_data
+        nsn = name_displayer.raw_sorted_name
+
+        plist = self.db.get_person_handles()
+
+        self.total = len(plist)
 
         if dfilter:
             handle_list = dfilter.apply(self.db, self.db.get_person_handles())
         else:
             handle_list = self.db.get_person_handles()
 
+        self.displayed = len(handle_list)
+
         self.mapper.clear_sort_names()
 
+        status = LongOpStatus(msg="Loading People",
+                              total_steps=len(handle_list),
+                              interval=len(handle_list)/10)
+        self.db.emit('long-op-start', (status,))
+        
         for handle in handle_list:
+            status.heartbeat()
             d = self.db.get_raw_person_data(handle)
-            if not (handle in skip or (dfilter and not dfilter.match(handle))):
+            if not handle in skip:
                 name_data = d[PeopleModel._NAME_COL]
 
                 group_name = ngn(self.db, name_data)
@@ -358,16 +375,21 @@ class PeopleModel(gtk.GenericTreeModel):
 
                 self.mapper.assign_sort_name(handle, sorted_name, group_name)
         
+        status.end()
+        
     def calculate_data(self, dfilter=None, skip=[]):
         """
-        Calculates the new path to node values for the model.
+        Calculate the new path to node values for the model.
         """
-	self.in_build  = True
+        self.in_build  = True
         self.lru_data  = LRU(_CACHE_SIZE)
         self.lru_name  = LRU(_CACHE_SIZE)
         self.lru_bdate = LRU(_CACHE_SIZE)
         self.lru_ddate = LRU(_CACHE_SIZE)
 
+        self.total = 0
+        self.displayed = 0
+
         if dfilter:
             self.dfilter = dfilter
             
@@ -380,7 +402,7 @@ class PeopleModel(gtk.GenericTreeModel):
 
         self.mapper.build_toplevel()
 
-	self.in_build  = False
+        self.in_build  = False
 
     def clear_cache(self):
         self.lru_data  = LRU(_CACHE_SIZE)
@@ -395,15 +417,15 @@ class PeopleModel(gtk.GenericTreeModel):
         self.mapper.assign_data()
 
     def on_get_flags(self):
-        '''returns the GtkTreeModelFlags for this particular type of model'''
+        """returns the GtkTreeModelFlags for this particular type of model"""
         return gtk.TREE_MODEL_ITERS_PERSIST
 
     def on_get_n_columns(self):
         return len(PeopleModel.COLUMN_DEFS)
 
     def on_get_path(self,  node):
-        '''returns the tree path (a tuple of indices at the various
-        levels) for a particular node.'''
+        """returns the tree path (a tuple of indices at the various
+        levels) for a particular node."""
         return self.mapper.get_path(node)
 
     def is_visable(self, handle):
@@ -436,15 +458,14 @@ class PeopleModel(gtk.GenericTreeModel):
                     data = self.lru_data[node]
                 except:
                     data = self.db.get_raw_person_data(str(node))
-		    if not self.in_build:
-			self.lru_data[node] = data
-                return PeopleModel.COLUMN_DEFS[col][PeopleModel.COLUMN_DEF_LIST](self,
-                                                                                 data, node)
+                    if not self.in_build:
+                        self.lru_data[node] = data
+                return PeopleModel.COLUMN_DEFS[col][PeopleModel.COLUMN_DEF_LIST](self, data, node)
             except:
                 return None
 
     def on_iter_next(self,  node):
-        '''returns the next node at this level of the tree'''
+        """returns the next node at this level of the tree"""
         return self.mapper.find_next_node(node)
 
     def on_iter_children(self, node):
@@ -452,7 +473,7 @@ class PeopleModel(gtk.GenericTreeModel):
         return self.mapper.first_child(node)
 
     def on_iter_has_child(self, node):
-        '''returns true if this node has children'''
+        """returns true if this node has children"""
         return self.mapper.has_child(node)
 
     def on_iter_n_children(self, node):
@@ -462,13 +483,13 @@ class PeopleModel(gtk.GenericTreeModel):
         return self.mapper.get_nth_child(node, n)
 
     def on_iter_parent(self, node):
-        '''returns the parent of this node'''
+        """returns the parent of this node"""
         return self.mapper.get_parent_of(node)
 
     def column_sort_name(self, data, node):
         n = Name()
         n.unserialize(data[PeopleModel._NAME_COL])
-        return NameDisplay.displayer.sort_string(n)
+        return name_displayer.sort_string(n)
 
     def column_spouse(self, data, node):
         spouses_names = u""
@@ -484,16 +505,16 @@ class PeopleModel(gtk.GenericTreeModel):
                 spouse = self.db.get_person_from_handle(spouse_id)
                 if len(spouses_names) > 0:
                     spouses_names += ", "
-                spouses_names += NameDisplay.displayer.display(spouse)
+                spouses_names += name_displayer.display(spouse)
         return spouses_names
 
     def column_name(self, data, node):
-	try:
-	    name = self.lru_name[node]
-	except:
-	    name = NameDisplay.displayer.raw_sorted_name(data[PeopleModel._NAME_COL])
-	    if not self.in_build:
-		self.lru_name[node] = name
+        try:
+            name = self.lru_name[node]
+        except:
+            name = name_displayer.raw_sorted_name(data[PeopleModel._NAME_COL])
+            if not self.in_build:
+                self.lru_name[node] = name
         return name
 
     def column_id(self, data, node):
@@ -509,12 +530,12 @@ class PeopleModel(gtk.GenericTreeModel):
         return PeopleModel._GENDER[data[PeopleModel._GENDER_COL]]
 
     def column_birth_day(self, data, node):
-	try:
-	    value = self.lru_bdate[node]
-	except:
-	    value = self._get_birth_data(data,node)
-	    if not self.in_build:
-		self.lru_bdate[node] = value
+        try:
+            value = self.lru_bdate[node]
+        except:
+            value = self._get_birth_data(data, node)
+            if not self.in_build:
+                self.lru_bdate[node] = value
         return value
 
     def _get_birth_data(self, data, node):
@@ -527,7 +548,11 @@ class PeopleModel(gtk.GenericTreeModel):
                 birth = self.db.get_event_from_handle(b.ref)
                 date_str = DateHandler.get_date(birth)
                 if date_str != "":
-                    return cgi.escape(date_str)
+                    retval = cgi.escape(date_str)
+                if not DateHandler.get_date_valid(birth):
+                    return invalid_date_format % retval
+                else:
+                    return retval
             except:
                 return u''
         
@@ -540,17 +565,21 @@ class PeopleModel(gtk.GenericTreeModel):
             if (etype in [EventType.BAPTISM, EventType.CHRISTEN]
                 and er.get_role() == EventRoleType.PRIMARY
                 and date_str != ""):
-                return "<i>%s</i>" % cgi.escape(date_str)
+                retval = u"<i>%s</i>" % cgi.escape(date_str)
+                if not DateHandler.get_date_valid(event):
+                    return invalid_date_format % retval
+                else:
+                    return retval
         
         return u""
 
     def column_death_day(self, data, node):
-	try:
-	    value = self.lru_ddate[node]
-	except:
-	    value = self._get_death_data(data,node)
-	    if not self.in_build:
-		self.lru_ddate[node] = value
+        try:
+            value = self.lru_ddate[node]
+        except:
+            value = self._get_death_data(data, node)
+            if not self.in_build:
+                self.lru_ddate[node] = value
         return value
 
     def _get_death_data(self, data, node):
@@ -563,7 +592,11 @@ class PeopleModel(gtk.GenericTreeModel):
                 event = self.db.get_event_from_handle(ref.ref)
                 date_str = DateHandler.get_date(event)
                 if date_str != "":
-                    return cgi.escape(date_str)
+                    retval = cgi.escape(date_str)
+                if not DateHandler.get_date_valid(event):
+                    return invalid_date_format % retval
+                else:
+                    return retval
             except:
                 return u''
         
@@ -573,11 +606,14 @@ class PeopleModel(gtk.GenericTreeModel):
             event = self.db.get_event_from_handle(er.ref)
             etype = event.get_type()
             date_str = DateHandler.get_date(event)
-            if (etype in [EventType.BURIAL, EventType.CREMATION]
+            if (etype in [EventType.BURIAL, EventType.CREMATION, EventType.CAUSE_DEATH]
                 and er.get_role() == EventRoleType.PRIMARY
                 and date_str):
-                return "<i>%s</i>" % cgi.escape(date_str)
-        
+                retval = "<i>%s</i>" % cgi.escape(date_str)
+                if not DateHandler.get_date_valid(event):
+                    return invalid_date_format % retval
+                else:
+                    return retval
         return u""
 
     def column_birth_place(self, data, node):
@@ -637,8 +673,8 @@ class PeopleModel(gtk.GenericTreeModel):
             er.unserialize(event_ref)
             event = self.db.get_event_from_handle(er.ref)
             etype = event.get_type()
-            if etype in [EventType.BURIAL, EventType.CREMATION]\
-               and er.get_role() == EventRoleType.PRIMARY:
+            if (etype in [EventType.BURIAL, EventType.CREMATION, EventType.CAUSE_DEATH]
+                and er.get_role() == EventRoleType.PRIMARY):
                 place_handle = event.get_place_handle()
                 if place_handle:
                     place = self.db.get_place_from_handle(place_handle)
@@ -670,7 +706,7 @@ class PeopleModel(gtk.GenericTreeModel):
         return None
 
     def column_tooltip(self, data, node):
-        if const.use_tips:
+        if const.USE_TIPS:
             return ToolTips.TipFromFunction(
                 self.db,
                 lambda: self.db.get_person_from_handle(data[0])
@@ -678,7 +714,6 @@ class PeopleModel(gtk.GenericTreeModel):
         else:
             return u''
         
-
     def column_int_id(self, data, node):
         return node
 
