@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _ButtonTab.py 10108 2008-02-24 18:58:45Z acraphae $
+# $Id: _ButtonTab.py 13370 2009-10-14 17:43:54Z gbritton $
 
 #-------------------------------------------------------------------------
 #
@@ -39,7 +39,7 @@ import gtk
 # GRAMPS classes
 #
 #-------------------------------------------------------------------------
-from GrampsWidgets import SimpleButton
+from widgets import SimpleButton
 from _GrampsTab import GrampsTab
 import Errors
 
@@ -98,7 +98,6 @@ class ButtonTab(GrampsTab):
         """
         self.dirty_selection = False
         GrampsTab.__init__(self,dbstate, uistate, track, name)
-        self.tooltips = gtk.Tooltips()
         self.create_buttons(share_button, move_buttons, jump_button)
 
     def create_buttons(self, share_button, move_buttons, jump_button):
@@ -113,22 +112,22 @@ class ButtonTab(GrampsTab):
         self.edit_btn = SimpleButton(gtk.STOCK_EDIT, self.edit_button_clicked)
         self.del_btn  = SimpleButton(gtk.STOCK_REMOVE, self.del_button_clicked)
 
-        self.tooltips.set_tip(self.add_btn, self._MSG['add'])
-        self.tooltips.set_tip(self.edit_btn, self._MSG['edit'])
-        self.tooltips.set_tip(self.del_btn, self._MSG['del'])
+        self.add_btn.set_tooltip_text(self._MSG['add'])
+        self.edit_btn.set_tooltip_text(self._MSG['edit'])
+        self.del_btn.set_tooltip_text(self._MSG['del'])
         
         if share_button:
             self.share_btn = SimpleButton(gtk.STOCK_INDEX, self.share_button_clicked)
-            self.tooltips.set_tip(self.share_btn, self._MSG['share'])
+            self.share_btn.set_tooltip_text(self._MSG['share'])
         else:
             self.share_btn = None
             
         if move_buttons:
             self.up_btn = SimpleButton(gtk.STOCK_GO_UP, self.up_button_clicked)
-            self.tooltips.set_tip(self.up_btn, self._MSG['up'])
+            self.up_btn.set_tooltip_text(self._MSG['up'])
             self.down_btn = SimpleButton(gtk.STOCK_GO_DOWN, 
                                                 self.down_button_clicked)
-            self.tooltips.set_tip(self.down_btn, self._MSG['down'])
+            self.down_btn.set_tooltip_text(self._MSG['down'])
         else:
             self.up_btn = None
             self.down_btn = None
@@ -146,24 +145,24 @@ class ButtonTab(GrampsTab):
 
         if jump_button:
             self.jump_btn = SimpleButton(gtk.STOCK_JUMP_TO, self.jump_button_clicked)
-            self.tooltips.set_tip(self.jump_btn, self._MSG['jump'])
+            self.jump_btn.set_tooltip_text(self._MSG['jump'])
         else:
             self.jump_btn = None
 
-        vbox = gtk.VBox()
-        vbox.set_spacing(6)
-        vbox.pack_start(self.add_btn, False)
+        hbox = gtk.HBox()
+        hbox.set_spacing(6)
+        hbox.pack_start(self.add_btn, False)
         if share_button:
-            vbox.pack_start(self.share_btn, False)
-        vbox.pack_start(self.edit_btn, False)
-        vbox.pack_start(self.del_btn, False)
+            hbox.pack_start(self.share_btn, False)
+        hbox.pack_start(self.edit_btn, False)
+        hbox.pack_start(self.del_btn, False)
         if move_buttons:
-            vbox.pack_start(self.up_btn, False)
-            vbox.pack_start(self.down_btn, False)
+            hbox.pack_start(self.up_btn, False)
+            hbox.pack_start(self.down_btn, False)
         if jump_button:
-            vbox.pack_start(self.jump_btn, False)
-        vbox.show_all()
-        self.pack_start(vbox, False)
+            hbox.pack_start(self.jump_btn, False)
+        hbox.show_all()
+        self.pack_start(hbox, False)
 
     def double_click(self, obj, event):
         """
@@ -274,7 +273,7 @@ class ButtonTab(GrampsTab):
         # explicitly, dirty_selection must make sure they do not interact
         if self.dirty_selection:
             return
-        if self.get_selected() != None:
+        if self.get_selected() is not None:
             self.edit_btn.set_sensitive(True)
             if self.jump_btn:
                 self.jump_btn.set_sensitive(True)
