@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EmbeddedList.py 11364 2008-11-29 21:39:44Z gburto01 $
+# $Id: _EmbeddedList.py 13088 2009-08-20 12:35:34Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -240,11 +240,15 @@ class EmbeddedList(ButtonTab):
         pass
 
     def _find_row(self, x, y):
-        row = self.tree.get_path_at_pos(x, y)
-        if row == None:
+        row = self.tree.get_dest_row_at_pos(x, y)
+        if row is None:
             return len(self.get_data())
         else:
-            return row[0][0]
+            if row[1] in (gtk.TREE_VIEW_DROP_BEFORE,
+                          gtk.TREE_VIEW_DROP_INTO_OR_BEFORE):
+                return row[0][0]
+            else:
+                return row[0][0]+1
 
     def _handle_drag(self, row, obj):
         self.get_data().insert(row, obj)
@@ -347,7 +351,7 @@ class EmbeddedList(ButtonTab):
         scroll.set_shadow_type(gtk.SHADOW_IN)
         scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         scroll.add(self.tree)
-        self.pack_start(scroll, True)
+        self.pack_end(scroll, True)
 
     def get_selected(self):
         """
@@ -417,7 +421,10 @@ class EmbeddedList(ButtonTab):
             name = self._column_names[pair[1]][0]
             renderer = gtk.CellRendererText()
             renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
-            column = gtk.TreeViewColumn(name, renderer, text=pair[1])
+            if name == _("Date"):
+                column = gtk.TreeViewColumn(name, renderer, markup=pair[1])
+            else:
+                column = gtk.TreeViewColumn(name, renderer, text=pair[1])
 
             # insert the colum into the tree
             column.set_resizable(True)
