@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditAddress.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _EditAddress.py 11905 2009-02-07 22:54:16Z gburto01 $
 
 """
 The EditAddress module provides the EditAddress class. This provides a
@@ -51,7 +52,7 @@ from _EditSecondary import EditSecondary
 from gen.lib import NoteType
 
 from DisplayTabs import SourceEmbedList, NoteTab
-from GrampsWidgets import MonitoredDate, MonitoredEntry, PrivacyButton
+from widgets import MonitoredDate, MonitoredEntry, PrivacyButton
 
 #-------------------------------------------------------------------------
 #
@@ -63,8 +64,6 @@ class EditAddress(EditSecondary):
     Displays a dialog that allows the user to edit an address.
     """
 
-    WIDTH_KEY = Config.ADDRESS_WIDTH
-    HEIGHT_KEY = Config.ADDRESS_HEIGHT
 
     def __init__(self, dbstate, uistate, track, addr, callback):
         """
@@ -76,6 +75,8 @@ class EditAddress(EditSecondary):
         EditSecondary.__init__(self, dbstate, uistate, track, addr, callback)
 
     def _local_init(self):
+        self.width_key = Config.ADDRESS_WIDTH
+        self.height_key = Config.ADDRESS_HEIGHT
         self.top = glade.XML(const.GLADE_FILE, "addr_edit","gramps")
         self.set_window(self.top.get_widget("addr_edit"),
                         self.top.get_widget("title"),
@@ -118,7 +119,7 @@ class EditAddress(EditSecondary):
                                   self.obj, self.db.readonly)
 
     def _connect_signals(self):
-        self.define_help_button(self.top.get_widget('help'),'adv-ad')
+        self.define_help_button(self.top.get_widget('help'))
         self.define_cancel_button(self.top.get_widget('cancel'))
         self.define_ok_button(self.top.get_widget('ok'),self.save)
 
