@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditChildRef.py 10428 2008-03-30 21:24:23Z dsblank $
+# $Id: _EditChildRef.py 11906 2009-02-07 23:02:58Z gburto01 $
 
 """
 The EditChildRef module provides the EditChildRef class. This provides a
@@ -49,9 +50,10 @@ import const
 from _EditSecondary import EditSecondary
 from gen.lib import NoteType
 import Errors
+import Config
 
 from DisplayTabs import SourceEmbedList, NoteTab
-from GrampsWidgets import MonitoredDataType, PrivacyButton
+from widgets import MonitoredDataType, PrivacyButton
 from BasicUtils import name_displayer
 
 #-------------------------------------------------------------------------
@@ -86,6 +88,8 @@ class EditChildRef(EditSecondary):
                                childref, callback)
 
     def _local_init(self):
+        self.width_key = Config.CHILD_REF_WIDTH
+        self.height_key = Config.CHILD_REF_HEIGHT
         self.top = glade.XML(const.GLADE_FILE, "cref_edit","gramps")
         self.set_window(self.top.get_widget("cref_edit"),
                         self.top.get_widget("title"),
@@ -119,7 +123,7 @@ class EditChildRef(EditSecondary):
             self.db.readonly)
 
     def _connect_signals(self):
-        self.define_help_button(self.top.get_widget('help'), 'adv-ad')
+        self.define_help_button(self.top.get_widget('help'))
         self.define_cancel_button(self.top.get_widget('cancel'))
         self.define_ok_button(self.ok_button, self.save)
         self.edit_button.connect('button-press-event', self.edit_child)
