@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditName.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _EditName.py 11905 2009-02-07 22:54:16Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
@@ -46,8 +47,8 @@ from BasicUtils import name_displayer
 from _EditSecondary import EditSecondary
 from gen.lib import NoteType
 from DisplayTabs import GrampsTab,SourceEmbedList,NoteTab
-from GrampsWidgets import (MonitoredEntry, MonitoredMenu, MonitoredDate, 
-                           MonitoredDataType, PrivacyButton)
+from widgets import (MonitoredEntry, MonitoredMenu, MonitoredDate, 
+                     MonitoredDataType, PrivacyButton)
 
 
 #-------------------------------------------------------------------------
@@ -100,15 +101,14 @@ class GeneralNameTab(GrampsTab):
 #-------------------------------------------------------------------------
 class EditName(EditSecondary):
 
-    WIDTH_KEY = Config.NAME_WIDTH
-    HEIGHT_KEY = Config.NAME_HEIGHT
-
     def __init__(self, dbstate, uistate, track, name, callback):
 
         EditSecondary.__init__(self, dbstate, uistate,
                                track, name, callback)
 
     def _local_init(self):
+        self.width_key = Config.NAME_WIDTH
+        self.height_key = Config.NAME_HEIGHT
         
         self.top = glade.XML(const.GLADE_FILE, "name_edit","gramps")
         self.set_window(self.top.get_widget("name_edit"),
@@ -141,7 +141,7 @@ class EditName(EditSecondary):
 
     def _connect_signals(self):
         self.define_cancel_button(self.top.get_widget('button119'))
-        self.define_help_button(self.top.get_widget('button131'),'adv-an')
+        self.define_help_button(self.top.get_widget('button131'))
         self.define_ok_button(self.top.get_widget('button118'),self.save)
 
     def _setup_fields(self):
