@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _EditSecondary.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _EditSecondary.py 11921 2009-02-08 14:37:57Z gburto01 $
 
 import ManagedWindow
 import GrampsDisplay
@@ -26,9 +27,6 @@ import Config
 
 class EditSecondary(ManagedWindow.ManagedWindow):
 
-    WIDTH_KEY = None
-    HEIGHT_KEY = None
-
     def __init__(self, state, uistate, track, obj, callback=None):
         """Create an edit window.  Associates a person with the window."""
 
@@ -50,12 +48,6 @@ class EditSecondary(ManagedWindow.ManagedWindow):
         self.show()
         self._post_init()
 
-    def _set_size(self):
-        if self.WIDTH_KEY:
-            width = Config.get(self.WIDTH_KEY)
-            height = Config.get(self.HEIGHT_KEY)
-            self.window.resize(width, height)
-
     def _local_init(self):
         """
         Derived class should do any pre-window initalization in this task.
@@ -124,20 +116,12 @@ class EditSecondary(ManagedWindow.ManagedWindow):
     def define_cancel_button(self,button):
         button.connect('clicked',self.close)
 
-    def define_help_button(self, button, tag, webpage='', section=''):
-        button.connect('clicked', lambda x: GrampsDisplay.help(tag, webpage,
+    def define_help_button(self, button, webpage='', section=''):
+        button.connect('clicked', lambda x: GrampsDisplay.help(webpage,
                                                                section))
 
     def close(self,*obj):
         for key in self.signal_keys:
             self.db.disconnect(key)
         self._cleanup_on_exit()
-        self._save_size()
         ManagedWindow.ManagedWindow.close(self)
-
-    def _save_size(self):
-        if self.HEIGHT_KEY:
-            (width, height) = self.window.get_size()
-            Config.set(self.WIDTH_KEY, width)
-            Config.set(self.HEIGHT_KEY, height)
-            Config.sync()
