@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: LdsUtils.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: LdsUtils.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Parses the lds.xml file to build the temple/code maps
@@ -33,7 +33,7 @@ from gettext import gettext as _
 
 LOG = logging.getLogger(".")
 
-class LdsTemples:
+class LdsTemples(object):
     """
     Parsing class for the LDS temples file
     """
@@ -66,14 +66,14 @@ class LdsTemples:
         returns True if the code is a valid LDS temple code according
         to the lds.xml file
         """
-        return self.__temple_to_abrev.get(code) != None
+        return self.__temple_to_abrev.get(code) is not None
 
     def is_valid_name(self, name):
         """
         returns True if the name matches a temple name (not code) in
         the lds.xml file
         """
-        return self.__temple_codes.get(name) != None
+        return self.__temple_codes.get(name) is not None
 
     def code(self, name):
         """
@@ -110,7 +110,7 @@ class LdsTemples:
         text = ''.join(self.__tlist)
 
         if tag == "code":
-            if self.__temple_codes.get(self.__current_temple) == None:
+            if self.__temple_codes.get(self.__current_temple) is None:
                 self.__temple_codes[self.__current_temple] = text
             self.__temple_to_abrev[text] = self.__current_temple
 
