@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ManagedWindow.py 10173 2008-03-02 23:32:01Z pez4brian $
+# $Id: ManagedWindow.py 12560 2009-05-21 17:58:31Z gbritton $
 
 """
 Provide the managed window interface, which allows GRAMPS to track
@@ -47,6 +48,7 @@ from gtk import glade
 #-------------------------------------------------------------------------
 import const
 import Errors
+import Config
 
 #-------------------------------------------------------------------------
 #
@@ -58,7 +60,7 @@ _win_top = '<ui><menubar name="MenuBar"><menu action="WindowsMenu">'
 _win_btm = '</menu></menubar></ui>'
 DISABLED = -1
 
-class GrampsWindowManager:
+class GrampsWindowManager(object):
     """
     Manage hierarchy of open GRAMPS windows.
 
@@ -138,7 +140,7 @@ class GrampsWindowManager:
         # starting with the given item.
         # Eventualy, every non-list item (leaf) will be reached
         # and the func(item,*args) will be called on that item.
-        if type(item) == list:
+        if isinstance(item, list):
             # If this item is a branch
             # close the children except for the first one
             for sub_item in item[1:]:
@@ -198,7 +200,7 @@ class GrampsWindowManager:
 
         # Make sure we have a track
         parent_item = self.get_item_from_track(track)
-        assert type(parent_item) == list or track == [], \
+        assert isinstance(parent_item, list) or track == [], \
                "Gwm: add_item: Incorrect track - Is parent not a leaf?"
 
         # Prepare a new item, depending on whether it is branch or leaf
@@ -220,7 +222,7 @@ class GrampsWindowManager:
         return new_track
 
     def call_back_factory(self, item):
-        if type(item) != list:
+        if not isinstance(item, list):
             def func(obj):
                 if item.window_id and self.id2item.get(item.window_id):
                     self.id2item[item.window_id].present()
@@ -233,7 +235,7 @@ class GrampsWindowManager:
         return str(item.window_id)
 
     def display_menu_list(self, data, action_data, mlist):
-        if type(mlist) in (list, tuple):
+        if isinstance(mlist, (list, tuple)):
             i = mlist[0]
             idval = self.generate_id(i)
             data.write('<menu action="M:%s">' % idval)
@@ -247,9 +249,9 @@ class GrampsWindowManager:
         action_data.append((idval, None, i.menu_label, None, None,
                             self.call_back_factory(i)))
 
-        if (type(mlist) in (list, tuple)) and (len(mlist) > 1):
+        if isinstance(mlist, (list, tuple)) and (len(mlist) > 1):
             for i in mlist[1:]:
-                if type(i) == list:
+                if isinstance(i, list):
                     self.display_menu_list(data, action_data, i)
                 else:
                     idval = self.generate_id(i)
@@ -257,7 +259,7 @@ class GrampsWindowManager:
                                % self.generate_id(i))        
                     action_data.append((idval, None, i.menu_label, None, None,
                                         self.call_back_factory(i)))
-        if type(mlist) in (list, tuple):
+        if isinstance(mlist, (list, tuple)):
             data.write('</menu>')
         
     def build_windows_menu(self):
@@ -283,7 +285,7 @@ class GrampsWindowManager:
 # Gramps Managed Window class
 #
 #-------------------------------------------------------------------------
-class ManagedWindow:
+class ManagedWindow(object):
     """
     Managed window base class.
     
@@ -292,7 +294,6 @@ class ManagedWindow:
     menu, keeping track of child windows, closing them on close/delete
     event, and presenting itself when selected or attempted to create again.
     """
-
     def __init__(self, uistate, track, obj):
         """
         Create child windows and add itself to menu, if not there already.
@@ -331,6 +332,8 @@ class ManagedWindow:
         menu_label, submenu_label = self.build_menu_names(obj)
         self._gladeobj = None
         self.isWindow = None
+        self.width_key = None
+        self.height_key = None
             
         if uistate.gwm.get_item_from_id(window_key):
             uistate.gwm.get_item_from_id(window_key).present()
@@ -379,6 +382,8 @@ class ManagedWindow:
         
         """
         self.isWindow = isWindow
+        self.msg = msg
+        self.titlelabel = title
         if self.isWindow :
             set_titles(self, title, text, msg)
         else :
@@ -386,6 +391,12 @@ class ManagedWindow:
             #closing the gtk.Window must also close ManagedWindow
             self.window = window
             self.window.connect('delete-event', self.close)
+    
+    def update_title(self, text):
+        if self.isWindow:
+            set_titles(self, self.titlelabel, text, self.msg)
+        else:
+            set_titles(self.window, self.titlelabel, text, self.msg)
 
     def build_menu_names(self, obj):
         return ('Undefined Menu','Undefined Submenu')
@@ -394,7 +405,7 @@ class ManagedWindow:
         return id(obj)
 
     def define_glade(self, top_module, glade_file=None):
-        if glade_file == None:
+        if glade_file is None:
             glade_file = const.GLADE_FILE
         self._gladeobj = glade.XML(glade_file, top_module, "gramps")
         return self._gladeobj
@@ -425,7 +436,7 @@ class ManagedWindow:
             Connect the OK button to a method that checks if all is ok, 
                 Do not call close, close is called here.
                 (if not ok, do self.window.run() to obtain new response )
-                TODO: remove close here and do close in BareReportDialog,
+                TODO: remove close here and do close in ReportDialog,
                       this can only be done, once all methods use modal_call()
                       instead of their own implementation
             Connect Cancel to do close, delete event is connected to close 
@@ -455,6 +466,7 @@ class ManagedWindow:
 
         Takes care of closing children and removing itself from menu.
         """
+        self._save_size()
         self.uistate.gwm.close_track(self.track)
         self.opened = False
         self.parent_window.present()
@@ -470,6 +482,24 @@ class ManagedWindow:
                    "ManagedWindow: self.window does not exist!"
             self.window.present()
 
+    def _set_size(self):
+        """
+        Set the dimensions of the window
+        """
+        if self.width_key is not None:
+            width = Config.get(self.width_key)
+            height = Config.get(self.height_key)
+            self.window.resize(width, height)
+
+    def _save_size(self):
+        """
+        Save the dimensions of the window to the config file
+        """
+        if self.width_key is not None:
+            (width, height) = self.window.get_size()
+            Config.set(self.width_key, width)
+            Config.set(self.height_key, height)
+            Config.sync()
 #-------------------------------------------------------------------------
 #
 # Helper functions
