@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _MergePlace.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: _MergePlace.py 12129 2009-02-26 09:36:41Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -48,7 +48,7 @@ import ManagedWindow
 # GRAMPS constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Entering_and_Editing_Data:_Detailed'
+WIKI_HELP_PAGE = '%s_-_Entering_and_Editing_Data:_Detailed_-_part_3' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Merge_Places')
 
 #-------------------------------------------------------------------------
@@ -98,7 +98,7 @@ class MergePlaces(ManagedWindow.ManagedWindow):
 
     def help(self, obj):
         """Display the relevant portion of GRAMPS manual"""
-        GrampsDisplay.help('adv-merge-places', webpage = WIKI_HELP_PAGE, section = WIKI_HELP_SEC)
+        GrampsDisplay.help(webpage = WIKI_HELP_PAGE, section = WIKI_HELP_SEC)
 
     def merge(self, obj):
         """
