@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Tool.py 10302 2008-03-14 04:25:30Z pez4brian $
+# $Id: _Tool.py 12560 2009-05-21 17:58:31Z gbritton $
 
 "ToolGeneration Framework"
 
@@ -48,9 +48,6 @@ from PluginUtils import (Options, OptionHandler, OptionList,
 # Constants
 #
 #-------------------------------------------------------------------------
-# Modes for running tools
-MODE_GUI = 1    # Standrt tool using GUI
-MODE_CLI = 2    # Command line interface (CLI)
 
 # Tool categories
 TOOL_DEBUG  = -1
@@ -74,7 +71,7 @@ tool_categories = {
 # Tool
 #
 #-------------------------------------------------------------------------
-class Tool:
+class Tool(object):
     """
     The Tool base class.  This is a base class for generating
     customized tools.  It cannot be used as is, but it can be easily
@@ -85,12 +82,13 @@ class Tool:
         from PluginUtils import MenuToolOptions
         self.db = dbstate.db
         self.person = dbstate.active
-        if issubclass(options_class, MenuToolOptions):
-            # FIXME: pass in person_id
-            self.options = options_class(name, None, dbstate)
-        elif type(options_class) == ClassType:
-            self.options = options_class(name)
-        elif type(options_class) == InstanceType:
+        try:
+            if issubclass(options_class, MenuToolOptions):
+                # FIXME: pass in person_id
+                self.options = options_class(name, None, dbstate)
+            else:   # must be some kind of class or we get a TypeError
+                self.options = options_class(name)
+        except TypeError:
             self.options = options_class
         self.options.load_previous_values()
 
@@ -150,7 +148,7 @@ class ActivePersonTool(Tool):
 # Command-line tool
 #
 #------------------------------------------------------------------------
-class CommandLineTool:
+class CommandLineTool(object):
     """
     Provide a way to run tool from the command line.
     
@@ -219,7 +217,7 @@ class CommandLineTool:
                                     self.options_help[self.show][1])
             print "   Available values are:"
             vals = self.options_help[self.show][2]
-            if type(vals) in [list,tuple]:
+            if isinstance(vals, (list, tuple)):
                 if self.options_help[self.show][3]:
                     for num in range(len(vals)):
                         print "      %d\t%s" % (num,vals[num])
