@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _CommandLineReport.py 11061 2008-09-15 02:10:00Z pez4brian $
+# $Id: _CommandLineReport.py 12805 2009-07-16 12:40:52Z bmcage $
 
 
 #-------------------------------------------------------------------------
@@ -40,7 +40,7 @@ log = logging.getLogger(".")
 # Gramps modules
 #
 #-------------------------------------------------------------------------
-import PluginUtils
+import gen
 import Utils
 import BaseDoc
 from BasicUtils import name_displayer
@@ -70,7 +70,7 @@ def _validate_options(options, dbase):
     for name in menu.get_all_option_names():
         option = menu.get_option_by_name(name)
 
-        if isinstance(option, PluginUtils.PersonOption):
+        if isinstance(option, gen.plug.menu.PersonOption):
             pid = option.get_value()
             person = dbase.get_person_from_gramps_id(pid)
             if not person:
@@ -79,29 +79,38 @@ def _validate_options(options, dbase):
                     phandle = dbase.get_person_handles()[0]
                     person = dbase.get_person_from_handle(phandle)
                     if not person:
-                        print "Please specify a person"
+                        print "ERROR: Please specify a person"
             if person:
                 option.set_value(person.get_gramps_id())
             
-        elif isinstance(option, PluginUtils.FamilyOption):
+        elif isinstance(option, gen.plug.menu.FamilyOption):
             fid = option.get_value()
             family = dbase.get_family_from_gramps_id(fid)
             if not family:
                 person = dbase.get_default_person()
-                family_list = person.get_family_handle_list()
+                family_list = []
+                family_handle = None
+                if person:
+                    family_list = person.get_family_handle_list()
                 if family_list:
                     family_handle = family_list[0]
                 else:
-                    family_handle = dbase.get_family_handles()[0]
-                family = dbase.get_family_from_handle(family_handle)
-                option.set_value(family.get_gramps_id())
+                    flist = dbase.get_family_handles()
+                    if flist:
+                        family_handle = flist[0]
+                if family_handle:
+                    family = dbase.get_family_from_handle(family_handle)
+                    option.set_value(family.get_gramps_id())
+                else:
+                    print "ERROR: Please specify a family"
+
 
 #------------------------------------------------------------------------
 #
 # Command-line report
 #
 #------------------------------------------------------------------------
-class CommandLineReport:
+class CommandLineReport(object):
     """
     Provide a way to generate report from the command line.
     """
@@ -125,6 +134,11 @@ class CommandLineReport:
         """
         Initialize the options that are hard-coded into the report system.
         """
+        pmgr = gen.plug.PluginManager.get_instance()
+        _textdoc_list = pmgr.get_text_doc_list()
+        _drawdoc_list = pmgr.get_draw_doc_list()
+        _bookdoc_list = pmgr.get_book_doc_list()
+        
         self.options_dict = {
             'of'        : self.option_class.handler.module_name,
             'off'       : self.option_class.handler.get_format_name(),
@@ -152,13 +166,13 @@ class CommandLineReport:
 
         if self.category == CATEGORY_TEXT:
             self.options_help['off'][2] = \
-                [ item[7] for item in PluginUtils.textdoc_list ]
+                [ item[6] for item in _textdoc_list ]
         elif self.category == CATEGORY_DRAW:
             self.options_help['off'][2] = \
-                [ item[6] for item in PluginUtils.drawdoc_list ]
+                [ item[6] for item in _drawdoc_list ]
         elif self.category == CATEGORY_BOOK:
             self.options_help['off'][2] = \
-                [ item[6] for item in PluginUtils.bookdoc_list ]
+                [ item[6] for item in _bookdoc_list ]
         else:
             self.options_help['off'][2] = "NA"
 
@@ -195,7 +209,7 @@ class CommandLineReport:
             self.options_dict[name] = option.get_value()
             self.options_help[name] = [ "", option.get_help() ]
             
-            if isinstance(option, PluginUtils.PersonOption):
+            if isinstance(option, gen.plug.menu.PersonOption):
                 id_list = []
                 for person_handle in self.database.get_person_handles():
                     person = self.database.get_person_from_handle(person_handle)
@@ -203,7 +217,7 @@ class CommandLineReport:
                         person.get_gramps_id(),
                         name_displayer.display(person)))
                 self.options_help[name].append(id_list)
-            elif isinstance(option, PluginUtils.FamilyOption):
+            elif isinstance(option, gen.plug.menu.FamilyOption):
                 id_list = []
                 for fhandle in self.database.get_family_handles():
                     family = self.database.get_family_from_handle(fhandle)
@@ -223,31 +237,31 @@ class CommandLineReport:
                         (family.get_gramps_id(), fname, mname)
                     id_list.append(text)
                 self.options_help[name].append(id_list)
-            elif isinstance(option, PluginUtils.NoteOption):
+            elif isinstance(option, gen.plug.menu.NoteOption):
                 id_list = []
                 for nhandle in self.database.get_note_handles():
                     note = self.database.get_note_from_handle(nhandle)
                     id_list.append(note.get_gramps_id())
                 self.options_help[name].append(id_list)
-            elif isinstance(option, PluginUtils.MediaOption):
+            elif isinstance(option, gen.plug.menu.MediaOption):
                 id_list = []
                 for mhandle in self.database.get_media_object_handles():
                     mobject = self.database.get_object_from_handle(mhandle)
                     id_list.append(mobject.get_gramps_id())
                 self.options_help[name].append(id_list)
-            elif isinstance(option, PluginUtils.PersonListOption):
+            elif isinstance(option, gen.plug.menu.PersonListOption):
                 self.options_help[name].append("")
-            elif isinstance(option, PluginUtils.NumberOption):
+            elif isinstance(option, gen.plug.menu.NumberOption):
                 self.options_help[name].append("A number")
-            elif isinstance(option, PluginUtils.BooleanOption):
+            elif isinstance(option, gen.plug.menu.BooleanOption):
                 self.options_help[name].append(["0\tno", "1\tyes"])
-            elif isinstance(option, PluginUtils.DestinationOption):
+            elif isinstance(option, gen.plug.menu.DestinationOption):
                 self.options_help[name].append("A file system path")
-            elif isinstance(option, PluginUtils.StringOption):
+            elif isinstance(option, gen.plug.menu.StringOption):
                 self.options_help[name].append("Any text")
-            elif isinstance(option, PluginUtils.TextOption):
+            elif isinstance(option, gen.plug.menu.TextOption):
                 self.options_help[name].append("Any text")
-            elif isinstance(option, PluginUtils.EnumeratedListOption):
+            elif isinstance(option, gen.plug.menu.EnumeratedListOption):
                 ilist = []
                 for (value, description) in option.get_items():
                     ilist.append("%s\t%s" % (value, description))
@@ -279,27 +293,29 @@ class CommandLineReport:
         
         self.option_class.handler.output = self.options_dict['of']
 
+        pmgr = gen.plug.PluginManager.get_instance()
+
         if self.category == CATEGORY_TEXT:
-            for item in PluginUtils.textdoc_list:
-                if item[7] == self.options_dict['off']:
+            for item in pmgr.get_text_doc_list():
+                if item[6] == self.options_dict['off']:
                     self.format = item[1]
             if self.format is None:
                 # Pick the first one as the default.
-                self.format = PluginUtils.textdoc_list[0][1]
+                self.format = pmgr.get_text_doc_list()[0][1]
         elif self.category == CATEGORY_DRAW:
-            for item in PluginUtils.drawdoc_list:
+            for item in pmgr.get_draw_doc_list():
                 if item[6] == self.options_dict['off']:
                     self.format = item[1]
             if self.format is None:
                 # Pick the first one as the default.
-                self.format = PluginUtils.drawdoc_list[0][1]
+                self.format = pmgr.get_draw_doc_list()[0][1]
         elif self.category == CATEGORY_BOOK:
-            for item in PluginUtils.bookdoc_list:
+            for item in pmgr.get_book_doc_list():
                 if item[6] == self.options_dict['off']:
                     self.format = item[1]
             if self.format is None:
                 # Pick the first one as the default.
-                self.format = PluginUtils.bookdoc_list[0][1]
+                self.format = pmgr.get_book_doc_list()[0][1]
         else:
             self.format = None
 
@@ -351,7 +367,7 @@ class CommandLineReport:
                                     self.options_help[self.show][1])
             print "   Available values are:"
             vals = self.options_help[self.show][2]
-            if type(vals) in [list,tuple]:
+            if isinstance(vals, (list, tuple)):
                 for val in vals:
                     print "      %s" % val
             else:
