@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2003-2006  Donald N. Allingham
+#               2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SelectFamily.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _SelectFamily.py 11923 2009-02-08 15:47:24Z gburto01 $
 
 #-------------------------------------------------------------------------
 #
@@ -34,6 +35,7 @@ from gettext import gettext as _
 #-------------------------------------------------------------------------
 from DisplayModels import FamilyModel
 from _BaseSelector import BaseSelector
+import Config
 
 #-------------------------------------------------------------------------
 #
@@ -42,6 +44,13 @@ from _BaseSelector import BaseSelector
 #-------------------------------------------------------------------------
 class SelectFamily(BaseSelector):
 
+    def _local_init(self):
+        """
+        Perform local initialisation for this class
+        """
+        self.width_key = Config.FAMILY_SEL_WIDTH
+        self.height_key = Config.FAMILY_SEL_HEIGHT
+
     def get_window_title(self):
         return _("Select Family")
         
