@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2005-2007  Donald N. Allingham
+# Copyright (C) 2008       Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -54,10 +55,9 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from PluginUtils import Plugins, Tool, PluginWindows, \
-     relationship_class, load_plugins, \
-     tool_list, report_list
-
+from PluginUtils import Tool, PluginWindows, \
+    ReportPluginDialog, ToolPluginDialog
+from gen.plug import PluginManager
 import ReportBase
 import DisplayState
 import const
@@ -70,7 +70,7 @@ import PageView
 import Navigation
 import RecentFiles
 from BasicUtils import name_displayer
-import GrampsWidgets
+import widgets
 import UndoHistory
 from DbLoader import DbLoader
 import GrampsDisplay
@@ -83,6 +83,7 @@ import ProgressDialog
 # Constants
 #
 #-------------------------------------------------------------------------
+_UNSUPPORTED = _("Unsupported")
 
 UIDEFAULT = '''<ui>
 <menubar name="MenuBar">
@@ -114,6 +115,7 @@ UIDEFAULT = '''<ui>
     <menuitem action="Sidebar"/>
     <menuitem action="Toolbar"/>    
     <menuitem action="Filter"/>    
+    <menuitem action="Fullscreen"/>    
     <separator/>
   </menu>
   <menu action="GoMenu">
@@ -173,12 +175,15 @@ UIDEFAULT = '''<ui>
 </ui>
 '''
 
+WIKI_HELP_PAGE_FAQ = '%s_-_FAQ' % const.URL_MANUAL_PAGE
+WIKI_HELP_PAGE_KEY = '%s_-_Keybindings' % const.URL_MANUAL_PAGE
+WIKI_HELP_PAGE_MAN = '%s' % const.URL_MANUAL_PAGE
 #-------------------------------------------------------------------------
 #
 # ViewManager
 #
 #-------------------------------------------------------------------------
-class ViewManager:
+class ViewManager(object):
     """
     Overview
     ========
@@ -213,13 +218,15 @@ class ViewManager:
         self.button_handlers = []
         self.buttons = []
         self.merge_ids = []
-        self.tips = gtk.Tooltips()
         self._key = None
         self.file_loaded = False
 
         self.show_sidebar = Config.get(Config.VIEW)
         self.show_toolbar = Config.get(Config.TOOLBAR_ON)
         self.show_filter = Config.get(Config.FILTER)
+        self.fullscreen = Config.get(Config.FULLSCREEN)
+        
+        self.__pmgr = PluginManager.get_instance()
 
         self.__build_main_window()
         self.__connect_signals()
@@ -236,7 +243,7 @@ class ViewManager:
         self.window.set_icon_from_file(const.ICON)
         self.window.set_default_size(width, height)
         
-        self.rel_class = relationship_class
+        self.rel_class = self.__pmgr.get_relationship_calculator()
 
         vbox = gtk.VBox()
         self.window.add(vbox)
@@ -248,6 +255,7 @@ class ViewManager:
         hbox.show_all()
 
         self.notebook = gtk.Notebook()
+        self.notebook.set_scrollable(True)
         self.notebook.set_show_tabs(False)
         self.notebook.show()
         self.__init_lists()
@@ -297,6 +305,9 @@ class ViewManager:
         else:
             self.toolbar.hide()
 
+        if self.fullscreen:
+            self.window.fullscreen()
+
         # Showing the main window is deferred so that
         # ArgHandler can work without it always shown
         # But we need to realize it here to have gtk.gdk.window handy
@@ -310,10 +321,10 @@ class ViewManager:
         self.progress.set_size_request(100, -1)
         self.progress.hide()
 
-        self.statusbar = GrampsWidgets.Statusbar()
+        self.statusbar = widgets.Statusbar()
         self.statusbar.show()
 
-        self.warnbtn = GrampsWidgets.WarnButton()
+        self.warnbtn = widgets.WarnButton()
 
         hbox2 = gtk.HBox()
         hbox2.set_spacing(4)
@@ -344,17 +355,8 @@ class ViewManager:
         openbtn = gtk.MenuToolButton('gramps-db')
         openbtn.connect('clicked', self.__open_activate)
         openbtn.set_sensitive(False)
-        open_tips = gtk.Tooltips()
-        openbtn.set_arrow_tooltip(
-            open_tips, 
-            _("Connect to a recent database"), 
-            _("Connect to a recent database"))
-        
-        openbtn.set_tooltip(
-            open_tips, 
-            _("Manage databases"), 
-            _("Manage databases")
-            )
+        openbtn.set_arrow_tooltip_text(_("Connect to a recent database"))
+        openbtn.set_tooltip_text(_("Manage databases"))
         openbtn.show()
         return openbtn
 
@@ -393,7 +395,7 @@ class ViewManager:
             ('About', gtk.STOCK_ABOUT, _('_About'), None, None, 
              display_about_box),
             ('PluginStatus', None, _('_Plugin Status'), None, None, 
-             self.plugin_status), 
+             self.__plugin_status), 
             ('FAQ', None, _('_FAQ'), None, None, faq_activate), 
             ('KeyBindings', None, _('_Key Bindings'), None, None, key_bindings),
             ('UserManual', gtk.STOCK_HELP, _('_User Manual'), 'F1', None, 
@@ -455,6 +457,8 @@ class ViewManager:
              self.show_toolbar ), 
             ('Filter', None, _('_Filter Sidebar'), None, None, 
              filter_toggle, self.show_filter), 
+            ('Fullscreen', None, _('F_ull Screen'), "F11", None, 
+             self.fullscreen_toggle, self.fullscreen), 
             ]
 
         self._undo_action_list = [
@@ -535,10 +539,10 @@ class ViewManager:
             self.actiongroup.set_visible(False)
             self.readonlygroup.set_visible(False)
         self.fileactions.set_sensitive(False)
-        self.__build_tools_menu(tool_list)
-        self.__build_report_menu(report_list)
+        self.__build_tools_menu(self.__pmgr.get_tool_list())
+        self.__build_report_menu(self.__pmgr.get_report_list())
         self.uistate.set_relationship_class()
-        self.uistate.connect('plugins-reloaded', 
+        self.__pmgr.connect('plugins-reloaded', 
                              self.__rebuild_report_and_tool_menus)
         self.fileactions.set_sensitive(True)
         self.uistate.widget.set_sensitive(True)
@@ -582,30 +586,17 @@ class ViewManager:
 
     def __do_load_plugins(self):
         """
-        Loads the plugins at initialization time.  We load the document 
-        generators and the plugins. The plugin status window is opened
-        on an error if the user has requested.
+        Loads the plugins at initialization time. The plugin status window is 
+        opened on an error if the user has requested.
         """
-        
-        # load document generators
-        self.uistate.status_text(_('Loading document formats...'))
-        error  = load_plugins(const.DOCGEN_DIR)
-        error |= load_plugins(const.USER_DOCGEN)
-
         # load plugins
         self.uistate.status_text(_('Loading plugins...'))
-        error |= load_plugins(const.PLUGINS_DIR)
-        error |= load_plugins(const.USER_PLUGINS)
+        error = self.__pmgr.load_plugins(const.PLUGINS_DIR)
+        error |= self.__pmgr.load_plugins(const.USER_PLUGINS)
 
-        #  get to ssee if we need to open the plugin status window
-        if Config.get(Config.POP_PLUGIN_STATUS) and error:
-            try:
-                PluginWindows.PluginStatus(self.state, self.uistate, [])
-            except Errors.WindowActiveError:
-                old_win = self.uistate.gwm.get_item_from_id(
-                    PluginWindows.PluginStatus)
-                old_win.close()
-                PluginWindows.PluginStatus(self.state, self.uistate, [])
+        #  get to see if we need to open the plugin status window
+        if error and Config.get(Config.POP_PLUGIN_STATUS):
+            self.__plugin_status()
 
         self.uistate.push_message(self.state, _('Ready'))
 
@@ -725,17 +716,14 @@ class ViewManager:
         import TipOfDay
         TipOfDay.TipOfDay(self.uistate)
 
-    def plugin_status(self, obj):
+    def __plugin_status(self, obj=None):
         """
         Display plugin status dialog
         """
         try:
-            PluginWindows.PluginStatus(self.state, self.uistate, [])
+            PluginWindows.PluginStatus(self.uistate, [])
         except Errors.WindowActiveError:
-            old_win = self.uistate.gwm.get_item_from_id(
-                PluginWindows.PluginStatus)
-            old_win.close()
-            PluginWindows.PluginStatus(self.state, self.uistate, [])
+            pass
 
     def sidebar_toggle(self, obj):
         """
@@ -767,6 +755,19 @@ class ViewManager:
             Config.set(Config.TOOLBAR_ON, False)
         Config.sync()
 
+    def fullscreen_toggle(self, obj):
+        """
+        Set the main Granps window fullscreen based on the value of the
+        toggle button. Save the setting in the config file.
+        """
+        if obj.get_active():
+            self.window.fullscreen()
+            Config.set(Config.FULLSCREEN, True)
+        else:
+            self.window.unfullscreen()
+            Config.set(Config.FULLSCREEN, False)
+        Config.sync()
+
     def register_view(self, view):
         """
         Allow other objects to register a view with the View Manager
@@ -782,15 +783,6 @@ class ViewManager:
             self.notebook.set_current_page(page_no)
         self.__vb_handlers_unblock()
 
-    def __setup_text_tips(self, use_text):
-        """
-        Enable/disable the text tips in the sidebar
-        """
-        if use_text:
-            self.tips.disable()
-        else:
-            self.tips.enable()
-    
     def __delete_pages(self):
         """
         Calls on_delete() for each view
@@ -806,7 +798,6 @@ class ViewManager:
         self.prev_nav = PageView.NAVIGATION_NONE
 
         use_text = Config.get(Config.SIDEBAR_TEXT)
-        self.__setup_text_tips(use_text)
         
         index = 0
         for page_def in self.views:
@@ -871,7 +862,7 @@ class ViewManager:
         button.set_alignment(0, 0.5)
 
         # add the tooltip
-        self.tips.set_tip(button, page_title)
+        button.set_tooltip_text(page_title)
 
         # connect the signal, along with the index as user data
         handler_id = button.connect('clicked', self.__vb_clicked, index)
@@ -971,12 +962,12 @@ class ViewManager:
         Initialize the navigation scheme
         """
         old_nav = self._navigation_type[self.prev_nav]
-        if old_nav[0] != None:
+        if old_nav[0] is not None:
             old_nav[0].disable()
 
         page_type = self.active_page.navigation_type()
         nav_type = self._navigation_type[page_type]
-        if nav_type[0] != None:
+        if nav_type[0] is not None:
             nav_type[0].enable()
 
     def change_page(self, obj, page, num=-1):
@@ -1254,7 +1245,7 @@ class ViewManager:
         Displays the Reports dialog
         """
         try:
-            Plugins.ReportPlugins(self.state, self.uistate, [])
+            ReportPluginDialog(self.state, self.uistate, [])
         except Errors.WindowActiveError:
             return
 
@@ -1263,7 +1254,7 @@ class ViewManager:
         Displays the Tools dialog
         """
         try:
-            Plugins.ToolPlugins(self.state, self.uistate, [])
+            ToolPluginDialog(self.state, self.uistate, [])
         except Errors.WindowActiveError:
             return          
         
@@ -1314,10 +1305,12 @@ class ViewManager:
             except Errors.WindowActiveError:
                 return
 
-    def __rebuild_report_and_tool_menus(self, tool_menu_list, report_menu_list):
+    def __rebuild_report_and_tool_menus(self):
         """
         Callback that rebuilds the tools and reports menu
         """
+        tool_menu_list = self.__pmgr.get_tool_list()
+        report_menu_list = self.__pmgr.get_report_list()
         self.__build_tools_menu(tool_menu_list)
         self.__build_report_menu(report_menu_list)
         self.uistate.set_relationship_class()
@@ -1362,10 +1355,10 @@ class ViewManager:
         hash_data = {}
         for item in item_list:
             if item[9]:
-                category = Plugins.UNSUPPORTED
+                category = _UNSUPPORTED
             else:
                 category = categories[item[3]]
-            if hash_data.has_key(category):
+            if category in hash_data:
                 hash_data[category].append(
                     (item[0], item[1], item[2], item[4], item[3], item[10]))
             else:
@@ -1374,7 +1367,7 @@ class ViewManager:
                 
         # Sort categories, skipping the unsupported
         catlist = [item for item in hash_data.keys()
-                   if item != Plugins.UNSUPPORTED]
+                   if item != _UNSUPPORTED]
         catlist.sort()
         for key in catlist:
             new_key = key.replace(' ', '-')
@@ -1392,11 +1385,11 @@ class ViewManager:
 
         # If there are any unsupported items we add separator
         # and the unsupported category at the end of the menu
-        if hash_data.has_key(Plugins.UNSUPPORTED):
+        if _UNSUPPORTED in hash_data:
             ofile.write('<separator/>')
-            ofile.write('<menu action="%s">' % Plugins.UNSUPPORTED)
-            actions.append((Plugins.UNSUPPORTED, None, Plugins.UNSUPPORTED))
-            lst = hash_data[Plugins.UNSUPPORTED]
+            ofile.write('<menu action="%s">' % _UNSUPPORTED)
+            actions.append((_UNSUPPORTED, None, _UNSUPPORTED))
+            lst = hash_data[_UNSUPPORTED]
             lst.sort(by_menu_name)
             for name in lst:
                 new_key = name[3].replace(' ', '-')
@@ -1409,9 +1402,7 @@ class ViewManager:
         return (ofile.getvalue(), actions)
 
 def display_about_box(obj):
-    """
-    Displays the About box.
-    """
+    """Display the About box."""
     about = GrampsAboutDialog()
     about.run()
     about.destroy()
@@ -1427,13 +1418,13 @@ def key_bindings(obj):
     """
     Display key bindings
     """
-    GrampsDisplay.help('keybind-lists', const.WIKI_KEYBINDINGS)
+    GrampsDisplay.help(webpage=WIKI_HELP_PAGE_KEY)
 
 def manual_activate(obj):
     """
     Display the GRAMPS manual
     """
-    GrampsDisplay.help('index')
+    GrampsDisplay.help(webpage=WIKI_HELP_PAGE_MAN)
 
 def report_bug_activate(obj):
     """
@@ -1463,7 +1454,7 @@ def faq_activate(obj):
     """
     Display FAQ
     """
-    GrampsDisplay.help("faq", webpage=const.WIKI_FAQ)
+    GrampsDisplay.help(webpage=WIKI_HELP_PAGE_FAQ)
 
 def by_menu_name(first, second):
     """
