@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: calendar.py 10103 2008-02-24 13:55:55Z acraphae $
+# $Id: calendar.py 11681 2009-01-22 10:15:01Z romjerome $
 
 """
 Provide calendar to sdn (serial date number) conversion.
@@ -466,18 +466,27 @@ def gregorian_ymd(sdn):
 
 def french_sdn(year, month, day):
     """Convert a French Republican Calendar date to an SDN number."""
-    return (year*_FR_DAYS_PER_4_YEARS)/4 + \
+    sdn = (year*_FR_DAYS_PER_4_YEARS)/4 + \
            (month-1)*_FR_DAYS_PER_MONTH + \
            day + _FR_SDN_OFFSET
+    # do not convert dates before 22.9.1792 or after 1.1.1806
+    if sdn < 2375840 or sdn > 2380688 :
+        return gregorian_sdn(year, month, day)
+    else:
+        return sdn
 
 def french_ymd(sdn):
     """Convert an SDN number to a French Republican Calendar date."""
-    temp = (sdn-_FR_SDN_OFFSET)*4 - 1
-    year = temp/_FR_DAYS_PER_4_YEARS
-    day_of_year = (temp%_FR_DAYS_PER_4_YEARS)/4
-    month = (day_of_year/_FR_DAYS_PER_MONTH)+1
-    day = (day_of_year%_FR_DAYS_PER_MONTH)+1
-    return (year, month, day)
+    # only between 22.9.1792 and 1.1.1806
+    if sdn >= 2375840 and sdn <= 2380688:
+        temp = (sdn-_FR_SDN_OFFSET)*4 - 1
+        year = temp/_FR_DAYS_PER_4_YEARS
+        day_of_year = (temp%_FR_DAYS_PER_4_YEARS)/4
+        month = (day_of_year/_FR_DAYS_PER_MONTH)+1
+        day = (day_of_year%_FR_DAYS_PER_MONTH)+1
+        return (year, month, day)
+    else:
+        return gregorian_ymd(sdn)
 
 def persian_sdn(year, month, day):
     """Convert a Persian date to an SDN number."""
@@ -539,3 +548,13 @@ def islamic_ymd(sdn):
     month = int(min(12, math.ceil((sdn-(29+islamic_sdn(year, 1, 1)))/29.5) + 1))
     day = int((sdn - islamic_sdn(year, month, 1)) + 1)
     return (year, month, day)
+
+def swedish_sdn(year, month, day):
+    """Convert a Swedish (almost Julian) date to an SDN number."""
+    return julian_sdn(year, month, day)-1
+
+def swedish_ymd(sdn):
+    """Convert an SDN number to a Swedish (almost Julian) calendar date."""
+    if sdn == 2346425:
+        return (1712,2,30)
+    return julian_ymd(sdn+1)
