@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: living.py 10785 2008-06-05 03:43:32Z pez4brian $
+# $Id: living.py 13629 2009-11-18 22:45:39Z bmcage $
 
 """
 Proxy class for the GRAMPS databases. Filter out all living people.
@@ -76,7 +76,7 @@ class LivingProxyDb(ProxyDbBase):
         """
         ProxyDbBase.__init__(self, dbase)
         self.mode = mode
-        if current_year != None:
+        if current_year is not None:
             self.current_date = Date()
             self.current_date.set_year(current_year)
         else:
@@ -153,7 +153,7 @@ class LivingProxyDb(ProxyDbBase):
         If no such Person exists, None is returned.
         """
         person = self.db.get_person_from_gramps_id(val)
-        if self.__is_living(person):
+        if person and self.__is_living(person):
             if self.mode == self.MODE_EXCLUDE_ALL:
                 return None
             else:
@@ -443,6 +443,8 @@ class LivingProxyDb(ProxyDbBase):
             new_name.set_first_name(_(u'Living'))
         else: # self.mode == self.MODE_INCLUDE_FULL_NAME_ONLY
             new_name.set_first_name(old_name.get_first_name())
+            new_name.set_suffix(old_name.get_suffix())
+            new_name.set_title(old_name.get_title())
         new_name.set_patronymic(old_name.get_patronymic())
         new_name.set_surname(old_name.get_surname())
         new_name.set_privacy(old_name.get_privacy())
@@ -452,10 +454,9 @@ class LivingProxyDb(ProxyDbBase):
         new_person.set_gender(person.get_gender())
         new_person.set_gramps_id(person.get_gramps_id())
         new_person.set_handle(person.get_handle())
+        new_person.set_change_time(person.get_change_time())
         new_person.set_family_handle_list(person.get_family_handle_list())
         new_person.set_parent_family_handle_list( 
                                         person.get_parent_family_handle_list() )
     
         return new_person
-
-
